@@ -21,11 +21,9 @@
 
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
-const Signals = imports.signals;
 const _ = imports.gettext.gettext;
 
 const EvDoc = imports.gi.EvinceDocument;
-const GdPrivate = imports.gi.GdPrivate;
 const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const Goa = imports.gi.Goa;
@@ -36,12 +34,8 @@ const Tracker = imports.gi.Tracker;
 const TrackerControl = imports.gi.TrackerControl;
 
 const ChangeMonitor = imports.changeMonitor;
-const Documents = imports.documents;
 const Format = imports.format;
-const Main = imports.main;
 const MainWindow = imports.mainWindow;
-const MainToolbar = imports.mainToolbar;
-const Manager = imports.manager;
 const Miners = imports.miners;
 const Notifications = imports.notifications;
 const Properties = imports.properties;
@@ -125,6 +119,9 @@ const Application = new Lang.Class({
         this.parent({ application_id: appid,
                       inactivity_timeout: 12000 });
 
+        this.add_main_option('version', 'v'.charCodeAt(0), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
+                             _("Show the version of the program"), null);
+
         this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
         this._searchProvider.connect('activate-result', Lang.bind(this, this._onActivateResult));
         this._searchProvider.connect('launch-search', Lang.bind(this, this._onLaunchSearch));
@@ -185,7 +182,7 @@ const Application = new Lang.Class({
             function() {
                 let state = settings.get_value('view-as');
                 if (state.get_string()[0] != action.state.get_string()[0])
-                    action.state = state;
+                    action.change_state(state);
             }));
     },
 
@@ -194,7 +191,7 @@ const Application = new Lang.Class({
             function() {
                 let state = settings.get_value('night-mode');
                 if (state.get_boolean() != action.state.get_boolean())
-                    action.state = state;
+                    action.change_state(state);
 
                 let gtkSettings = Gtk.Settings.get_default();
                 gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
@@ -210,7 +207,7 @@ const Application = new Lang.Class({
             function() {
                 let state = settings.get_value('sort-by');
                 if (state.get_string()[0] != action.state.get_string()[0])
-                    action.state = state;
+                    action.change_state(state);
             }));
     },
 
@@ -237,8 +234,11 @@ const Application = new Lang.Class({
         settings.set_value('night-mode', GLib.Variant.new('b', !state.get_boolean()));
     },
 
-    _onActionFullscreen: function() {
-        modeController.toggleFullscreen();
+    _onActionFullscreen: function(action) {
+        let state = action.get_state();
+        let newState = !state.get_boolean();
+        action.change_state(GLib.Variant.new('b', newState));
+        modeController.setFullscreen(newState);
     },
 
     _onActionViewAs: function(action, parameter) {
@@ -251,63 +251,6 @@ const Application = new Lang.Class({
             settings.set_value('sort-by', parameter);
     },
 
-    _onActionOpenCurrent: function() {
-        let doc = documentManager.getActiveItem();
-        if (doc)
-            doc.open(this._mainWindow.get_screen(), Gtk.get_current_event_time());
-    },
-
-    _onActionPrintCurrent: function() {
-        let doc = documentManager.getActiveItem();
-        if (doc)
-            doc.print(this._mainWindow);
-    },
-
-    _onActionToggle: function(action) {
-        let state = action.get_state();
-        action.change_state(GLib.Variant.new('b', !state.get_boolean()));
-    },
-
-    _onActionProperties: function() {
-        let doc = documentManager.getActiveItem();
-        if (!doc)
-            return;
-
-        let dialog = new Properties.PropertiesDialog(doc.id);
-        dialog.connect('response', Lang.bind(this,
-            function(widget, response) {
-                widget.destroy();
-            }));
-    },
-
-    _initActions: function() {
-        this._actionEntries.forEach(Lang.bind(this,
-            function(actionEntry) {
-                let state = actionEntry.state;
-                let parameterType = actionEntry.parameter_type ?
-                    GLib.VariantType.new(actionEntry.parameter_type) : null;
-                let action;
-
-                if (state)
-                    action = Gio.SimpleAction.new_stateful(actionEntry.name,
-                        parameterType, actionEntry.state);
-                else
-                    action = new Gio.SimpleAction({ name: actionEntry.name,
-                        parameter_type: parameterType });
-
-                if (actionEntry.create_hook)
-                    actionEntry.create_hook.apply(this, [action]);
-
-                if (actionEntry.callback)
-                    action.connect('activate', Lang.bind(this, actionEntry.callback));
-
-                if (actionEntry.accels)
-                    this.set_accels_for_action('app.' + actionEntry.name, actionEntry.accels);
-
-                this.add_action(action);
-            }));
-    },
-
     _connectActionsToMode: function() {
         this._actionEntries.forEach(Lang.bind(this,
             function(actionEntry) {
@@ -322,28 +265,14 @@ const Application = new Lang.Class({
                     modeController.connect('window-mode-changed', Lang.bind(this,
                         function() {
                             let mode = modeController.getWindowMode();
+                            let enable = actionEntry.window_modes.indexOf(mode) != -1;
                             let action = this.lookup_action(actionEntry.name);
-                            let enable = false;
-                            for (let idx in actionEntry.window_modes) {
-                                if (mode == actionEntry.window_modes[idx]) {
-                                    enable = true;
-                                    break;
-                                }
-                            }
                             action.set_enabled(enable);
                         }));
                 }
             }));
     },
 
-    _initAppMenu: function() {
-        let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/Documents/ui/app-menu.ui');
-
-        let menu = builder.get_object('app-menu');
-        this.set_app_menu(menu);
-    },
-
     _createMiners: function(callback) {
         let count = 3;
 
@@ -536,74 +465,49 @@ const Application = new Lang.Class({
 
         this._actionEntries = [
             { name: 'quit',
-              callback: this._onActionQuit,
+              callback: Lang.bind(this, this._onActionQuit),
               accels: ['<Primary>q'] },
             { name: 'about',
-              callback: this._onActionAbout },
+              callback: Lang.bind(this, this._onActionAbout) },
             { name: 'help',
-              callback: this._onActionHelp,
+              callback: Lang.bind(this, this._onActionHelp),
               accels: ['F1'] },
             { name: 'fullscreen',
-              callback: this._onActionFullscreen,
-              create_hook: this._fullscreenCreateHook,
+              callback: Lang.bind(this, this._onActionFullscreen),
+              state: GLib.Variant.new('b', false),
+              create_hook: Lang.bind(this, this._fullscreenCreateHook),
               accels: ['F11'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
+              window_mode: WindowMode.WindowMode.PREVIEW_EV },
             { name: 'night-mode',
-              callback: this._onActionNightMode,
-              create_hook: this._nightModeCreateHook,
+              callback: Lang.bind(this, this._onActionNightMode),
+              create_hook: Lang.bind(this, this._nightModeCreateHook),
               state: settings.get_value('night-mode') },
             { name: 'gear-menu',
-              callback: this._onActionToggle,
+              callback: Utils.actionToggleCallback,
               state: GLib.Variant.new('b', false),
               accels: ['F10'] },
             { name: 'view-as',
-              callback: this._onActionViewAs,
-              create_hook: this._viewAsCreateHook,
+              callback: Lang.bind(this, this._onActionViewAs),
+              create_hook: Lang.bind(this, this._viewAsCreateHook),
               parameter_type: 's',
               state: settings.get_value('view-as'),
               window_modes: [WindowMode.WindowMode.COLLECTIONS,
                              WindowMode.WindowMode.DOCUMENTS,
                              WindowMode.WindowMode.SEARCH] },
             { name: 'sort-by',
-              callback: this._onActionSortBy,
-              create_hook: this._sortByCreateHook,
+              callback: Lang.bind(this, this._onActionSortBy),
+              create_hook: Lang.bind(this, this._sortByCreateHook),
               parameter_type: 's',
               state: settings.get_value('sort-by'),
               window_modes: [WindowMode.WindowMode.COLLECTIONS,
                              WindowMode.WindowMode.DOCUMENTS,
                              WindowMode.WindowMode.SEARCH] },
-            { name: 'open-current',
-              callback: this._onActionOpenCurrent,
-              window_modes: [WindowMode.WindowMode.PREVIEW,
-                             WindowMode.WindowMode.PREVIEW_LOK] },
-            { name: 'edit-current' },
             { name: 'view-current',
               window_mode: WindowMode.WindowMode.EDIT },
-            { name: 'present-current',
-              window_mode: WindowMode.WindowMode.PREVIEW,
-              callback: this._onActionToggle,
-              state: GLib.Variant.new('b', false),
-              accels: ['F5'] },
-            { name: 'print-current', accels: ['<Primary>p'],
-              callback: this._onActionPrintCurrent },
             { name: 'search',
-              callback: this._onActionToggle,
+              callback: Utils.actionToggleCallback,
               state: GLib.Variant.new('b', false),
               accels: ['<Primary>f'] },
-            { name: 'find-next', accels: ['<Primary>g'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'find-prev', accels: ['<Shift><Primary>g'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'zoom-in', accels: ['<Primary>plus', '<Primary>equal'],
-              window_modes: [WindowMode.WindowMode.PREVIEW,
-                             WindowMode.WindowMode.PREVIEW_LOK] },
-            { name: 'zoom-out', accels: ['<Primary>minus'],
-              window_modes: [WindowMode.WindowMode.PREVIEW,
-                             WindowMode.WindowMode.PREVIEW_LOK] },
-            { name: 'rotate-left', accels: ['<Primary>Left'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'rotate-right', accels: ['<Primary>Right'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'select-all', accels: ['<Primary>a'],
               window_modes: [WindowMode.WindowMode.COLLECTIONS,
                              WindowMode.WindowMode.DOCUMENTS,
@@ -612,21 +516,6 @@ const Application = new Lang.Class({
               window_modes: [WindowMode.WindowMode.COLLECTIONS,
                              WindowMode.WindowMode.DOCUMENTS,
                              WindowMode.WindowMode.SEARCH] },
-            { name: 'properties',
-              callback: this._onActionProperties,
-              window_modes: [WindowMode.WindowMode.PREVIEW,
-                             WindowMode.WindowMode.PREVIEW_LOK] },
-            { name: 'bookmark-page',
-              callback: this._onActionToggle,
-              state: GLib.Variant.new('b', false),
-              accels: ['<Primary>d'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'places',
-              accels: ['<Primary>b'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'copy',
-              accels: ['<Primary>c'],
-              window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'search-source',
               parameter_type: 's',
               state: GLib.Variant.new('s', Search.SearchSourceStock.ALL),
@@ -647,11 +536,10 @@ const Application = new Lang.Class({
                              WindowMode.WindowMode.SEARCH] }
         ];
 
-        this._initActions();
-        this._initAppMenu();
-
         if (!this.isBooks)
             this._initGettingStarted();
+
+        Utils.populateActionGroup(this, this._actionEntries, 'app');
     },
 
     _createWindow: function() {
@@ -687,6 +575,15 @@ const Application = new Lang.Class({
         this.parent(connection, path);
     },
 
+    vfunc_handle_local_options: function(options) {
+        if (options.contains('version')) {
+            print(pkg.version);
+            return 0;
+        }
+
+        return -1;
+    },
+
     vfunc_activate: function() {
         if (!this._mainWindow) {
             this._createWindow();
@@ -735,7 +632,7 @@ const Application = new Lang.Class({
 
     _onActivateResult: function(provider, urn, terms, timestamp) {
         this._createWindow();
-        modeController.setWindowMode(WindowMode.WindowMode.PREVIEW);
+        modeController.setWindowMode(WindowMode.WindowMode.PREVIEW_EV);
 
         let doc = documentManager.getItemById(urn);
         if (doc) {
@@ -761,7 +658,7 @@ const Application = new Lang.Class({
             let modeChangeId = modeController.connect('window-mode-changed', Lang.bind(this,
                 function(object, newMode) {
                     if (newMode == WindowMode.WindowMode.EDIT
-                        || newMode == WindowMode.WindowMode.PREVIEW)
+                        || newMode == WindowMode.WindowMode.PREVIEW_EV)
                         return;
 
                     modeController.disconnect(modeChangeId);
