@@ -22,6 +22,7 @@
 const EvDocument = imports.gi.EvinceDocument;
 const EvView = imports.gi.EvinceView;
 const LOKView = imports.lokview;
+const EPUBView = imports.epubview;
 const GdkPixbuf = imports.gi.GdkPixbuf;
 const Gio = imports.gi.Gio;
 const Gd = imports.gi.Gd;
@@ -49,7 +50,8 @@ const Utils = imports.utils;
 const ViewType = {
     NONE: 0,
     EV: 1,
-    LOK: 2
+    LOK: 2,
+    EPUB: 3
 };
 
 const DeleteItemJob = new Lang.Class({
@@ -366,10 +368,6 @@ const DocCommon = new Lang.Class({
         }
     },
 
-    load: function() {
-        log('Error: DocCommon implementations must override load');
-    },
-
     canEdit: function() {
         log('Error: DocCommon implementations must override canEdit');
     },
@@ -383,9 +381,6 @@ const DocCommon = new Lang.Class({
     },
 
     canPrint: function(docModel) {
-        if (this.collection)
-            return false;
-
         if (!docModel)
             return false;
 
@@ -608,8 +603,7 @@ const DocCommon = new Lang.Class({
     },
 
     loadLocal: function(passwd, cancellable, callback) {
-        if (this.mimeType == 'application/epub+zip' ||
-            this.mimeType == 'application/x-mobipocket-ebook' ||
+        if (this.mimeType == 'application/x-mobipocket-ebook' ||
             this.mimeType == 'application/x-fictionbook+xml' ||
             this.mimeType == 'application/x-zip-compressed-fb2') {
             let exception = new GLib.Error(Gio.IOErrorEnum,
@@ -630,6 +624,11 @@ const DocCommon = new Lang.Class({
             return;
         }
 
+        if (EPUBView.isEpub(this.mimeType) && Application.application.isBooks) {
+            callback(this, null, null);
+            return;
+        }
+
         GdPrivate.pdf_loader_load_uri_async(this.uri, passwd, cancellable, Lang.bind(this,
             function(source, res) {
                 try {
@@ -711,6 +710,8 @@ const DocCommon = new Lang.Class({
     updateViewType: function() {
         if (LOKView.isOpenDocumentFormat(this.mimeType) && !Application.application.isBooks) {
             this.viewType = ViewType.LOK;
+        } else if (EPUBView.isEpub(this.mimeType) && Application.application.isBooks) {
+            this.viewType = ViewType.EPUB;
         } else {
             this.viewType = ViewType.EV;
         }
@@ -1193,8 +1194,6 @@ const DocumentManager = new Lang.Class({
     _init: function() {
         this.parent();
 
-        this._activeDocModel = null;
-        this._activeDocModelIds = [];
         this._loaderCancellable = null;
 
         this._activeCollection = null;
@@ -1394,14 +1393,6 @@ const DocumentManager = new Lang.Class({
             return;
         }
 
-        // save loaded model and signal
-        this._activeDocModel = docModel;
-        if (this._activeDocModel)
-            this._activeDocModel.set_continuous(false);
-
-        // load metadata
-        this._connectMetadata(docModel);
-
         this.emit('load-finished', doc, docModel);
     },
 
@@ -1500,40 +1491,5 @@ const DocumentManager = new Lang.Class({
             this._loaderCancellable.cancel();
             this._loaderCancellable = null;
         }
-
-        // clear any previously loaded document model
-        if (this._activeDocModel) {
-            this._activeDocModelIds.forEach(Lang.bind(this,
-                function(id) {
-                    this._activeDocModel.disconnect(id);
-                }));
-
-            this.metadata = null;
-            this._activeDocModel = null;
-            this._activeDocModelIds = [];
-        }
-    },
-
-    _connectMetadata: function(docModel) {
-        if (!docModel)
-            return;
-        let evDoc = docModel.get_document();
-        let file = Gio.File.new_for_uri(evDoc.get_uri());
-        if (!GdPrivate.is_metadata_supported_for_file(file))
-            return;
-
-        this.metadata = new GdPrivate.Metadata({ file: file });
-
-        let [res, val] = this.metadata.get_int('page');
-        if (res)
-            docModel.set_page(val);
-
-        // save current page in metadata
-        this._activeDocModelIds.push(
-            docModel.connect('page-changed', Lang.bind(this,
-                function(source, oldPage, newPage) {
-                    this.metadata.set_int('page', newPage);
-                }))
-        );
     }
 });
