@@ -18,26 +18,16 @@
  */
 
 const WebKit = imports.gi.WebKit2;
-const Soup = imports.gi.Soup;
-const Gd = imports.gi.Gd;
-const GdPrivate = imports.gi.GdPrivate;
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const _ = imports.gettext.gettext;
 
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
-const Signals = imports.signals;
 
 const Application = imports.application;
 const MainToolbar = imports.mainToolbar;
-const Searchbar = imports.searchbar;
-const Utils = imports.utils;
-const View = imports.view;
 const WindowMode = imports.windowMode;
-const Documents = imports.documents;
 
 const _BLANK_URI = "about:blank";
 
@@ -49,7 +39,6 @@ const EditView = new Lang.Class({
         this._uri = null;
 
         this.parent();
-        this.get_style_context().add_class('documents-scrolledwin');
 
         let context = WebKit.WebContext.get_default();
 
@@ -69,17 +58,6 @@ const EditView = new Lang.Class({
 
         this.show_all();
 
-        this._editAction = Application.application.lookup_action('edit-current');
-        this._editAction.enabled = false;
-        this._editAction.connect('activate', Lang.bind(this,
-            function() {
-                let doc = Application.documentManager.getActiveItem();
-                if (!doc)
-                    return;
-                Application.modeController.setWindowMode(WindowMode.WindowMode.EDIT);
-                this.setUri (doc.uri);
-            }));
-
         this._viewAction = Application.application.lookup_action('view-current');
         this._viewAction.enabled = false;
         this._viewAction.connect('activate', Lang.bind(this,
@@ -87,9 +65,6 @@ const EditView = new Lang.Class({
                 Application.modeController.goBack();
             }));
 
-        this._printAction = Application.application.lookup_action('print-current');
-        this._printAction.set_enabled(false);
-
         Application.documentManager.connect('load-started',
                                             Lang.bind(this, this._onLoadStarted));
         Application.documentManager.connect('load-finished',
@@ -98,19 +73,12 @@ const EditView = new Lang.Class({
     },
 
     _onLoadStarted: function() {
-        this._editAction.enabled = false;
         this._viewAction.enabled = false;
-        this._printAction.set_enabled(false);
     },
 
     _onLoadFinished: function(manager, doc, docModel) {
-        if (doc.uri) {
-            if (doc.canEdit())
-                this._editAction.enabled = true;
+        if (doc.uri)
             this._viewAction.enabled = true;
-            if (doc.canPrint(docModel))
-                this._printAction.set_enabled(true);
-        }
     },
 
     _createView: function() {
