@@ -24,9 +24,7 @@ const Mainloop = imports.mainloop;
 
 const Application = imports.application;
 const MainToolbar = imports.mainToolbar;
-const Notifications = imports.notifications;
 const Password = imports.password;
-const Preview = imports.preview;
 const Edit = imports.edit;
 const Search = imports.search;
 const Selections = imports.selections;
@@ -35,10 +33,9 @@ const WindowMode = imports.windowMode;
 const Documents = imports.documents;
 
 const EvView = imports.gi.EvinceView;
+const EvinceView = imports.evinceview;
 const LOKView = imports.lokview;
-const Gd = imports.gi.Gd;
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
+const EPUBView = imports.epubview;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const _ = imports.gettext.gettext;
@@ -50,9 +47,10 @@ const Embed = new Lang.Class({
     Name: 'Embed',
     Extends: Gtk.Box,
 
-    _init: function() {
+    _init: function(mainWindow) {
         this._loadShowId = 0;
         this._searchState = null;
+        this._window = mainWindow;
 
         this.parent({ orientation: Gtk.Orientation.VERTICAL,
                       visible: true });
@@ -87,12 +85,6 @@ const Embed = new Lang.Class({
         this._search = new View.ViewContainer(WindowMode.WindowMode.SEARCH);
         this._stack.add_named(this._search, 'search');
 
-        this._previewEv = new Preview.PreviewView(this._stackOverlay);
-        this._stack.add_named(this._previewEv, 'preview-ev');
-
-        this._previewLok = new LOKView.LOKView(this._stackOverlay);
-        this._stack.add_named(this._previewLok, 'preview-lok');
-
         this._edit = new Edit.EditView();
         this._stack.add_named(this._edit, 'edit');
 
@@ -150,11 +142,10 @@ const Embed = new Lang.Class({
         case WindowMode.WindowMode.DOCUMENTS:
             view = this._documents;
             break;
-        case WindowMode.WindowMode.PREVIEW:
-            view = this._previewEv;
-            break;
+        case WindowMode.WindowMode.PREVIEW_EV:
         case WindowMode.WindowMode.PREVIEW_LOK:
-            view = this._previewLok;
+        case WindowMode.WindowMode.PREVIEW_EPUB:
+            view = this._preview;
             break;
         case WindowMode.WindowMode.SEARCH:
             view = this._search;
@@ -187,14 +178,13 @@ const Embed = new Lang.Class({
         case WindowMode.WindowMode.DOCUMENTS:
             page = 'documents';
             break;
-        case WindowMode.WindowMode.PREVIEW:
-            page = 'preview-ev';
-            break;
         case WindowMode.WindowMode.SEARCH:
             page = 'search';
             break;
+        case WindowMode.WindowMode.PREVIEW_EV:
         case WindowMode.WindowMode.PREVIEW_LOK:
-            page = 'preview-lok';
+        case WindowMode.WindowMode.PREVIEW_EPUB:
+            page = 'preview';
             break;
         default:
             throw(new Error('Not handled'));
@@ -236,7 +226,7 @@ const Embed = new Lang.Class({
         let windowMode = Application.modeController.getWindowMode();
         if (windowMode == WindowMode.WindowMode.SEARCH && doc)
             return;
-        if (windowMode == WindowMode.WindowMode.PREVIEW)
+        if (windowMode == WindowMode.WindowMode.PREVIEW_EV)
             return;
 
         let searchType = Application.searchTypeManager.getActiveItem();
@@ -274,15 +264,18 @@ const Embed = new Lang.Class({
         case WindowMode.WindowMode.SEARCH:
             this._prepareForOverview(newMode, oldMode);
             break;
-        case WindowMode.WindowMode.PREVIEW:
+        case WindowMode.WindowMode.PREVIEW_EV:
             if (oldMode == WindowMode.WindowMode.EDIT)
                 Application.documentManager.reloadActiveItem();
-            this._prepareForPreview();
+            this._prepareForPreview(EvinceView.EvinceView);
             break;
         case WindowMode.WindowMode.PREVIEW_LOK:
             if (oldMode == WindowMode.WindowMode.EDIT)
                 Application.documentManager.reloadActiveItem();
-            this._prepareForLOKView();
+            this._prepareForPreview(LOKView.LOKView);
+            break;
+        case WindowMode.WindowMode.PREVIEW_EPUB:
+            this._prepareForPreview(EPUBView.EPUBView);
             break;
         case WindowMode.WindowMode.EDIT:
             this._prepareForEdit();
@@ -294,10 +287,9 @@ const Embed = new Lang.Class({
             break;
         }
 
-        if (this._toolbar.searchbar) {
+        if (this._toolbar.searchbar)
             this._toolbar.searchbar.connectJS('activate-result',
-                                               Lang.bind(this, this._onActivateResult));
-        }
+                                              Lang.bind(this, this._onActivateResult));
     },
 
     _restoreSearch: function() {
@@ -323,8 +315,9 @@ const Embed = new Lang.Class({
 
     _onActiveItemChanged: function(manager, doc) {
         let windowMode = Application.modeController.getWindowMode();
-        let showSearch = (windowMode == WindowMode.WindowMode.PREVIEW && !doc
+        let showSearch = (windowMode == WindowMode.WindowMode.PREVIEW_EV && !doc
                           || windowMode == WindowMode.WindowMode.SEARCH && !doc);
+
         if (showSearch)
             this._restoreSearch();
         else
@@ -343,8 +336,10 @@ const Embed = new Lang.Class({
     _onLoadStarted: function(manager, doc) {
         if (LOKView.isOpenDocumentFormat(doc.mimeType))
             Application.modeController.setWindowMode(WindowMode.WindowMode.PREVIEW_LOK);
+        else if (EPUBView.isEpub(doc.mimeType))
+            Application.modeController.setWindowMode(WindowMode.WindowMode.PREVIEW_EPUB);
         else
-            Application.modeController.setWindowMode(WindowMode.WindowMode.PREVIEW);
+            Application.modeController.setWindowMode(WindowMode.WindowMode.PREVIEW_EV);
 
         this._clearLoadTimer();
         this._loadShowId = Mainloop.timeout_add(_PDF_LOADER_TIMEOUT, Lang.bind(this,
@@ -361,28 +356,7 @@ const Embed = new Lang.Class({
         this._clearLoadTimer();
         this._spinner.stop();
 
-        switch (doc.viewType) {
-        case Documents.ViewType.EV:
-            if (docModel) {
-                if (Application.application.isBooks)
-                    docModel.set_sizing_mode(EvView.SizingMode.FIT_PAGE);
-                else
-                    docModel.set_sizing_mode(EvView.SizingMode.AUTOMATIC);
-                docModel.set_page_layout(EvView.PageLayout.AUTOMATIC);
-                this._toolbar.setModel(docModel);
-                this._previewEv.setModel(docModel);
-                this._previewEv.grab_focus();
-            }
-            this._stack.set_visible_child_name('preview-ev');
-            break;
-        case Documents.ViewType.LOK:
-            this._stack.set_visible_child_name('preview-lok');
-            break;
-        case Documents.ViewType.NONE:
-        default:
-            log('Something bad happened and the document type is unset');
-            break;
-        }
+        this._stack.set_visible_child_name('preview');
     },
 
     _onLoadError: function(manager, doc, message, exception) {
@@ -403,6 +377,15 @@ const Embed = new Lang.Class({
             }));
     },
 
+    _clearPreview: function() {
+        if (this._preview) {
+            this._preview.destroy();
+            this._preview = null;
+        }
+
+        this._window.insert_action_group('view', null);
+    },
+
     _prepareForOverview: function(newMode, oldMode) {
         let createToolbar = (oldMode != WindowMode.WindowMode.COLLECTIONS &&
                              oldMode != WindowMode.WindowMode.DOCUMENTS &&
@@ -425,10 +408,7 @@ const Embed = new Lang.Class({
             break;
         }
 
-        if (this._previewEv)
-            this._previewEv.reset();
-        if (this._previewLok)
-            this._previewLok.reset();
+        this._clearPreview();
         if (this._edit)
             this._edit.setUri(null);
 
@@ -445,60 +425,49 @@ const Embed = new Lang.Class({
         this._stack.set_visible_child_name(visibleChildName);
     },
 
-    _prepareForPreview: function() {
+    _prepareForPreview: function(constructor) {
+        this._clearPreview();
         if (this._edit)
             this._edit.setUri(null);
         if (this._toolbar)
             this._toolbar.destroy();
 
+        this._preview = new constructor(this._stackOverlay, this._window);
+        this._window.insert_action_group('view', this._preview.actionGroup);
+        this._stack.add_named(this._preview, 'preview');
+
         // pack the toolbar
-        this._toolbar = new Preview.PreviewToolbar(this._previewEv);
+        this._toolbar = this._preview.createToolbar();
         this._titlebar.add(this._toolbar);
 
-        this._stack.set_visible_child_name('preview-ev');
+        this._stack.set_visible_child_name('preview');
     },
 
     _prepareForEdit: function() {
-        if (this._previewEv)
-            this._previewEv.setModel(null);
+        this._clearPreview();
         if (this._toolbar)
             this._toolbar.destroy();
 
         // pack the toolbar
-        this._toolbar = new Edit.EditToolbar(this._previewEv);
+        this._toolbar = new Edit.EditToolbar(this._preview);
         this._titlebar.add(this._toolbar);
 
+        let doc = Application.documentManager.getActiveItem();
+        this._edit.setUri(doc.uri);
         this._stack.set_visible_child_name('edit');
     },
 
-    _prepareForLOKView: function() {
-        if (this._previewEv)
-            this._previewEv.setModel(null);
-        if (this._edit)
-            this._edit.setUri(null);
-        if (this._toolbar)
-            this._toolbar.destroy();
-
-        // pack the toolbar
-        this._toolbar = new LOKView.LOKViewToolbar(this._previewLok);
-        this._titlebar.add(this._toolbar);
-
-        this._stack.set_visible_child_name('preview-lok');
-    },
-
     getMainToolbar: function() {
         let windowMode = Application.modeController.getWindowMode();
         let fullscreen = Application.modeController.getFullscreen();
 
-        if (fullscreen && (windowMode == WindowMode.WindowMode.PREVIEW))
-            return this._previewEv.getFullscreenToolbar();
+        if (fullscreen && (windowMode == WindowMode.WindowMode.PREVIEW_EV))
+            return this._preview.getFullscreenToolbar();
         else
             return this._toolbar;
     },
 
     getPreview: function() {
-        //FIXME When we can pass clicks and key presses
-        //to the view, we'll need to grab the real current view
-        return this._previewEv;
+        return this._preview;
     }
 });
