@@ -21,16 +21,13 @@
  */
 
 const Gd = imports.gi.Gd;
-const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
-const Pango = imports.gi.Pango;
 
 const Gettext = imports.gettext;
 const _ = imports.gettext.gettext;
 
 const Lang = imports.lang;
-const Mainloop = imports.mainloop;
 
 const Application = imports.application;
 const Searchbar = imports.searchbar;
@@ -73,6 +70,10 @@ const MainToolbar = new Lang.Class({
             }));
     },
 
+    createSearchbar: function() {
+        return null;
+    },
+
     _onLoadErrorOrPassword: function() {
         this._handleEvent = false;
     },
@@ -87,12 +88,40 @@ const MainToolbar = new Lang.Class({
 
     addSearchButton: function() {
         let searchButton = new Gtk.ToggleButton({ image: new Gtk.Image ({ icon_name: 'edit-find-symbolic' }),
-                                                  tooltip_text: _("Search"),
+                                                  tooltip_text: Gettext.pgettext("toolbar button tooltip", "Search"),
                                                   action_name: 'app.search' });
         this.toolbar.pack_end(searchButton);
         return searchButton;
     },
 
+    _onFullscreenStateChanged: function() {
+        let state = Application.application.get_action_state('fullscreen');
+        if (state.get_boolean())
+            this._fullscreenButton.image.icon_name ='view-restore-symbolic';
+        else
+            this._fullscreenButton.image.icon_name ='view-fullscreen-symbolic';
+    },
+
+    addFullscreenButton: function() {
+        let fullscreenButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'view-fullscreen-symbolic' }),
+                                                tooltip_text: _("Fullscreen"),
+                                                action_name: 'app.fullscreen' });
+        this.toolbar.pack_end(fullscreenButton);
+        Application.application.connect('action-state-changed::fullscreen',
+            Lang.bind(this, this._onFullscreenStateChanged));
+        this._fullscreenButton = fullscreenButton;
+        this._onFullscreenStateChanged();
+        return fullscreenButton;
+    },
+
+    addNightmodeButton: function() {
+        let nightmodeButton = new Gtk.ToggleButton({ image: new Gtk.Image ({ icon_name: 'display-brightness-symbolic' }),
+                                                     tooltip_text: _("Night Mode"),
+                                                     action_name: 'app.night-mode' });
+        this.toolbar.pack_end(nightmodeButton);
+        return nightmodeButton;
+    },
+
     addBackButton: function() {
         let backButton = new Gtk.Button({ image: new Gtk.Image({ icon_name: 'go-previous-symbolic' }),
                                           tooltip_text: _("Back") });
