@@ -29,8 +29,6 @@ const Mainloop = imports.mainloop;
 
 const Application = imports.application;
 const Embed = imports.embed;
-const Selections = imports.selections;
-const Utils = imports.utils;
 const WindowMode = imports.windowMode;
 
 const _ = imports.gettext.gettext;
@@ -50,7 +48,8 @@ const MainWindow = new Lang.Class({
                       width_request: _WINDOW_MIN_WIDTH,
                       height_request: _WINDOW_MIN_HEIGHT,
                       window_position: Gtk.WindowPosition.CENTER,
-                      show_menubar: false });
+                      show_menubar: false,
+                      title: _("Documents") });
 
         // apply the last saved window size and position
         let size = Application.settings.get_value('window-size');
@@ -81,7 +80,7 @@ const MainWindow = new Lang.Class({
         this._fsId = Application.modeController.connect('fullscreen-changed',
             Lang.bind(this, this._onFullscreenChanged));
 
-        this._embed = new Embed.Embed();
+        this._embed = new Embed.Embed(this);
         this.add(this._embed);
     },
 
@@ -152,7 +151,7 @@ const MainWindow = new Lang.Class({
             handled = false;
             break;
         case WindowMode.WindowMode.EDIT:
-        case WindowMode.WindowMode.PREVIEW:
+        case WindowMode.WindowMode.PREVIEW_EV:
             Application.documentManager.setActiveItem(null);
             Application.modeController.goBack();
             break;
@@ -194,14 +193,15 @@ const MainWindow = new Lang.Class({
         switch (Application.modeController.getWindowMode()) {
         case WindowMode.WindowMode.NONE:
             return false;
-        case WindowMode.WindowMode.PREVIEW:
+        case WindowMode.WindowMode.PREVIEW_EV:
+        case WindowMode.WindowMode.PREVIEW_EPUB:
+        case WindowMode.WindowMode.PREVIEW_LOK:
             return this._handleKeyPreview(event);
         case WindowMode.WindowMode.COLLECTIONS:
         case WindowMode.WindowMode.DOCUMENTS:
         case WindowMode.WindowMode.SEARCH:
             return this._handleKeyOverview(event);
         case WindowMode.WindowMode.EDIT:
-        case WindowMode.WindowMode.PREVIEW_LOK: //FIXME should be same as preview
             return false;
         default:
             throw(new Error('Not handled'));
@@ -238,8 +238,10 @@ const MainWindow = new Lang.Class({
         let def_mod_mask = Gtk.accelerator_get_default_mod_mask();
         let preview = this._embed.getPreview();
         let state = event.get_state()[1];
+        let windowMode = Application.modeController.getWindowMode();
 
-        if (keyval == Gdk.KEY_Escape) {
+        if (keyval == Gdk.KEY_Escape &&
+            windowMode == WindowMode.WindowMode.PREVIEW_EV) {
             let model = preview.getModel();
 
             if (preview.controlsVisible && (model != null)) {
@@ -255,25 +257,32 @@ const MainWindow = new Lang.Class({
         if (((keyval == Gdk.KEY_Page_Up) &&
             ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) ||
             ((keyval == Gdk.KEY_Left) && ((state & def_mod_mask) == 0))) {
-            preview.view.previous_page();
+            preview.goPrev();
             return true;
         }
 
         if (((keyval == Gdk.KEY_Page_Down) &&
             ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) ||
             ((keyval == Gdk.KEY_Right) && ((state & def_mod_mask) == 0))) {
-            preview.view.next_page();
+            preview.goNext();
             return true;
         }
 
         if (keyval == Gdk.KEY_Page_Up) {
-            preview.view.scroll(Gtk.ScrollType.PAGE_BACKWARD, false);
-            return true;
+            try {
+                preview.scroll(Gtk.ScrollType.PAGE_BACKWARD);
+                return true;
+            } catch (e) {
+            }
         }
 
-        if (keyval == Gdk.KEY_Page_Down) {
-            preview.view.scroll(Gtk.ScrollType.PAGE_FORWARD, false);
-            return true;
+        if (keyval == Gdk.KEY_space ||
+            keyval == Gdk.KEY_Page_Down) {
+            try {
+                preview.scroll(Gtk.ScrollType.PAGE_FORWARD);
+                return true;
+            } catch (e) {
+            }
         }
 
         return false;
