@@ -23,16 +23,11 @@ const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
-const Tracker = imports.gi.Tracker;
-const _ = imports.gettext.gettext;
 
 const Lang = imports.lang;
-const Mainloop = imports.mainloop;
-const Signals = imports.signals;
 
 const Application = imports.application;
 const Manager = imports.manager;
-const Tweener = imports.tweener.tweener;
 const Utils = imports.utils;
 
 const Searchbar = new Lang.Class({
@@ -44,14 +39,13 @@ const Searchbar = new Lang.Class({
 
         this.parent();
 
-        // subclasses will create this._searchEntry and this._searchContainer
-        // GtkWidgets
-        this.createSearchWidgets();
+        // subclasses will create this.searchEntry
+        let searchWidget = this.createSearchWidget();
 
-        this.add(this._searchContainer);
-        this.connect_entry(this._searchEntry);
+        this.add(searchWidget);
+        this.connect_entry(this.searchEntry);
 
-        this._searchEntry.connect('search-changed', Lang.bind(this,
+        this.searchEntry.connect('search-changed', Lang.bind(this,
             function() {
                 if (this.searchChangeBlocked)
                     return;
@@ -85,8 +79,8 @@ const Searchbar = new Lang.Class({
             this.conceal();
     },
 
-    createSearchWidgets: function() {
-        log('Error: Searchbar implementations must override createSearchWidgets');
+    createSearchWidget: function() {
+        log('Error: Searchbar implementations must override createSearchWidget');
     },
 
     entryChanged: function() {
@@ -95,7 +89,7 @@ const Searchbar = new Lang.Class({
 
     handleEvent: function(event) {
         // Skip if the search bar is shown and the focus is elsewhere
-        if (this.search_mode_enabled && !this._searchEntry.is_focus)
+        if (this.search_mode_enabled && !this.searchEntry.is_focus)
             return false;
 
         let keyval = event.get_keyval()[1];
@@ -106,7 +100,7 @@ const Searchbar = new Lang.Class({
 
         let retval = this.handle_event(event);
         if (retval == Gdk.EVENT_STOP)
-            this._searchEntry.grab_focus_without_selecting();
+            this.searchEntry.grab_focus_without_selecting();
         return retval;
     },
 
@@ -118,7 +112,7 @@ const Searchbar = new Lang.Class({
         this.search_mode_enabled = false;
 
         // clear all the search properties when hiding the entry
-        this._searchEntry.set_text('');
+        this.searchEntry.set_text('');
     }
 });
 Utils.addJSSignalMethods(Searchbar.prototype);
@@ -127,11 +121,12 @@ const Dropdown = new Lang.Class({
     Name: 'Dropdown',
     Extends: Gtk.Popover,
 
-    _init: function(relativeTo) {
-        this.parent({ relative_to: relativeTo, position: Gtk.PositionType.BOTTOM });
+    _init: function() {
+        this.parent({ position: Gtk.PositionType.BOTTOM });
 
         let grid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
-                                  row_homogeneous: true });
+                                  row_homogeneous: true,
+                                  visible: true });
         this.add(grid);
 
         [Application.sourceManager,
@@ -173,7 +168,7 @@ const OverviewSearchbar = new Lang.Class({
         this._onActiveTypeChanged();
         this._onActiveMatchChanged();
 
-        this._searchEntry.set_text(Application.searchController.getString());
+        this.searchEntry.set_text(Application.searchController.getString());
         this.connect('destroy', Lang.bind(this,
             function() {
                 Application.sourceManager.disconnect(sourcesId);
@@ -183,12 +178,12 @@ const OverviewSearchbar = new Lang.Class({
             }));
     },
 
-    createSearchWidgets: function() {
+    createSearchWidget: function() {
         // create the search entry
-        this._searchEntry = new Gd.TaggedEntry({ width_request: 500 });
-        this._searchEntry.connect('tag-clicked',
+        this.searchEntry = new Gd.TaggedEntry({ width_request: 500 });
+        this.searchEntry.connect('tag-clicked',
             Lang.bind(this, this._onTagClicked));
-        this._searchEntry.connect('tag-button-clicked',
+        this.searchEntry.connect('tag-button-clicked',
             Lang.bind(this, this._onTagButtonClicked));
 
         this._sourceTag = new Gd.TaggedEntryTag();
@@ -199,41 +194,28 @@ const OverviewSearchbar = new Lang.Class({
         this._searchChangedId = Application.searchController.connect('search-string-changed',
             Lang.bind(this, this._onSearchStringChanged));
 
-        this._searchEntry.connect('destroy', Lang.bind(this,
+        this.searchEntry.connect('destroy', Lang.bind(this,
             function() {
                 Application.searchController.disconnect(this._searchChangedId);
             }));
 
         // create the dropdown button
-        this._dropdownButton = new Gtk.ToggleButton(
-            { child: new Gtk.Image({ icon_name: 'go-down-symbolic',
-                                     icon_size: Gtk.IconSize.MENU }) });
-        this._dropdownButton.get_style_context().add_class('raised');
-        this._dropdownButton.get_style_context().add_class('image-button');
-        this._dropdownButton.connect('toggled', Lang.bind(this,
-            function() {
-                let active = this._dropdownButton.get_active();
-                if(active)
-                    this._dropdown.show_all();
-            }));
+        let dropdown = new Dropdown();
+        this._dropdownButton = new Gtk.MenuButton({ popover: dropdown });
 
-        this._dropdown = new Dropdown(this._dropdownButton);
-        this._dropdown.connect('closed', Lang.bind(this,
-            function() {
-                this._dropdownButton.set_active(false);
-            }));
+        let box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
+                                halign: Gtk.Align.CENTER });
+        box.get_style_context().add_class('linked');
 
-        this._searchContainer = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                              halign: Gtk.Align.CENTER });
-        this._searchContainer.get_style_context().add_class('linked');
+        box.add(this.searchEntry);
+        box.add(this._dropdownButton);
+        box.show_all();
 
-        this._searchContainer.add(this._searchEntry);
-        this._searchContainer.add(this._dropdownButton);
-        this._searchContainer.show_all();
+        return box;
     },
 
     entryChanged: function() {
-        let currentText = this._searchEntry.get_text();
+        let currentText = this.searchEntry.get_text();
 
         Application.searchController.disconnect(this._searchChangedId);
         Application.searchController.setString(currentText);
@@ -244,7 +226,7 @@ const OverviewSearchbar = new Lang.Class({
     },
 
     _onSearchStringChanged: function(controller, string) {
-        this._searchEntry.set_text(string);
+        this.searchEntry.set_text(string);
     },
 
     _onActiveCollectionChanged: function(manager, collection) {
@@ -256,7 +238,7 @@ const OverviewSearchbar = new Lang.Class({
         if (Application.searchController.getString() != '' ||
             searchType.id != 'all') {
             Application.searchTypeManager.setActiveItemById('all');
-            this._searchEntry.set_text('');
+            this.searchEntry.set_text('');
         }
     },
 
@@ -264,13 +246,13 @@ const OverviewSearchbar = new Lang.Class({
         let item = manager.getActiveItem();
 
         if (item.id == 'all') {
-            this._searchEntry.remove_tag(tag);
+            this.searchEntry.remove_tag(tag);
         } else {
             tag.set_label(item.name);
-            this._searchEntry.add_tag(tag);
+            this.searchEntry.add_tag(tag);
         }
 
-        this._searchEntry.grab_focus_without_selecting();
+        this.searchEntry.grab_focus_without_selecting();
     },
 
     _onActiveSourceChanged: function() {
