@@ -21,12 +21,10 @@
 
 const Gd = imports.gi.Gd;
 const GdPrivate = imports.gi.GdPrivate;
-const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 
-const Documents = imports.documents;
 const Application = imports.application;
 
 const Lang = imports.lang;
@@ -122,3 +120,38 @@ function addJSSignalMethods(proto) {
     proto.emitJS = Signals._emit;
     proto.disconnectAllJS = Signals._disconnectAll;
 }
+
+function actionToggleCallback(action) {
+    let state = action.get_state();
+    action.change_state(GLib.Variant.new('b', !state.get_boolean()));
+}
+
+function populateActionGroup(actionGroup, actionEntries, prefix) {
+    actionEntries.forEach(function(actionEntry) {
+        let state = actionEntry.state;
+        let parameterType = actionEntry.parameter_type ?
+            GLib.VariantType.new(actionEntry.parameter_type) : null;
+        let action;
+
+        if (state)
+            action = Gio.SimpleAction.new_stateful(actionEntry.name,
+                                                   parameterType, actionEntry.state);
+        else
+            action = new Gio.SimpleAction({ name: actionEntry.name,
+                                            parameter_type: parameterType });
+
+        if (actionEntry.create_hook)
+            actionEntry.create_hook(action);
+
+        if (actionEntry.callback)
+            action.connect('activate', actionEntry.callback);
+
+        if (actionEntry.stateChanged)
+            action.connect('notify::state', actionEntry.stateChanged);
+
+        if (actionEntry.accels)
+            Application.application.set_accels_for_action(prefix + '.' + actionEntry.name, actionEntry.accels);
+
+        actionGroup.add_action(action);
+    });
+}
