@@ -33,9 +33,7 @@ const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
-const Documents = imports.documents;
 const ErrorBox = imports.errorBox;
-const TrackerUtils = imports.trackerUtils;
 const WindowMode = imports.windowMode;
 const Utils = imports.utils;
 
@@ -461,8 +459,8 @@ const ViewContainer = new Lang.Class({
     _getFirstDocument: function() {
         let doc = null;
 
-        let [success, iter] = this._model.get_iter_first();
-        if (success) {
+        let iter = this._model.get_iter_first()[1];
+        if (iter) {
             let id = this._model.get_value(iter, Gd.MainColumns.ID);
             doc = Application.documentManager.getItemById(id);
         }
