@@ -19,21 +19,18 @@
  *
  */
 
-const Gdk = imports.gi.Gdk;
-
 const Lang = imports.lang;
 const Signals = imports.signals;
 
-const Application = imports.application;
-
 const WindowMode = {
     NONE: 0,
     DOCUMENTS: 1,
-    PREVIEW: 2,
+    PREVIEW_EV: 2,
     PREVIEW_LOK: 3,
-    EDIT: 4,
-    COLLECTIONS: 5,
-    SEARCH: 6
+    PREVIEW_EPUB: 4,
+    EDIT: 5,
+    COLLECTIONS: 6,
+    SEARCH: 7,
 };
 
 const ModeController = new Lang.Class({
@@ -60,7 +57,7 @@ const ModeController = new Lang.Class({
          * provider. It is easier to special case it here instead of all
          * over the code.
          */
-        if (this._mode == WindowMode.PREVIEW && oldMode == WindowMode.NONE && steps == 1)
+        if (this._mode == WindowMode.PREVIEW_EV && oldMode == WindowMode.NONE && steps == 1)
           oldMode = WindowMode.DOCUMENTS;
 
         if (oldMode == WindowMode.NONE)
@@ -107,16 +104,12 @@ const ModeController = new Lang.Class({
         this.emit('fullscreen-changed', this._fullscreen);
     },
 
-    toggleFullscreen: function() {
-        this.setFullscreen(!this._fullscreen);
-    },
-
     getFullscreen: function() {
         return this._fullscreen;
     },
 
     getCanFullscreen: function() {
-        return (this._mode == WindowMode.PREVIEW || this._mode == WindowMode.EDIT);
+        return (this._mode == WindowMode.PREVIEW_EV || this._mode == WindowMode.EDIT);
     }
 });
 Signals.addSignalMethods(ModeController.prototype);
